@@ -1,7 +1,7 @@
 # ----------------------------------------------------------------------------------------------------------
 #  Copyright 2000-2006 by Alex Peeters [alex.peeters@citap.be]
 # ----------------------------------------------------------------------------------------------------------
-# 2006/07/15, v3.000.010, package ASNMTAP::Asnmtap::Plugins::SOAP Object-Oriented Perl
+# 2006/09/16, v3.000.011, package ASNMTAP::Asnmtap::Plugins::SOAP Object-Oriented Perl
 # ----------------------------------------------------------------------------------------------------------
 
 # Class name  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -32,7 +32,7 @@ BEGIN {
 
   @ASNMTAP::Asnmtap::Plugins::SOAP::EXPORT_OK   = ( @{ $ASNMTAP::Asnmtap::Plugins::SOAP::EXPORT_TAGS{ALL} } );
 
-  $ASNMTAP::Asnmtap::Plugins::SOAP::VERSION     = 3.000.010;
+  $ASNMTAP::Asnmtap::Plugins::SOAP::VERSION     = 3.000.011;
 }
 
 # Utility methods - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -121,12 +121,14 @@ sub get_soap_request {
     for ( $transportStatus ) {
       /500 Can_t connect to/ &&
         do { $$asnmtapInherited->pluginValues ( { stateValue => $ERRORS{UNKNOWN}, error => $transportStatus }, $TYPE{REPLACE} ); return $ERRORS{UNKNOWN}; last; };
+      /500 configure certs failed/ &&
+        do { $$asnmtapInherited->pluginValues ( { stateValue => $ERRORS{UNKNOWN}, error => $transportStatus }, $TYPE{REPLACE} ); return $ERRORS{UNKNOWN}; last; };
       /500 Connect failed/ &&
         do { $$asnmtapInherited->pluginValues ( { stateValue => $ERRORS{UNKNOWN}, error => $transportStatus }, $TYPE{REPLACE} ); return $ERRORS{UNKNOWN}; last; };
       /500 proxy connect failed/ &&
         do { $$asnmtapInherited->pluginValues ( { stateValue => $ERRORS{UNKNOWN}, error => $transportStatus }, $TYPE{REPLACE} ); return $ERRORS{UNKNOWN}; last; };
-      /500 Internal Server Error/ &&
-        do { $$asnmtapInherited->pluginValues ( { stateValue => $ERRORS{UNKNOWN}, error => $transportStatus }, $TYPE{REPLACE} ); return $ERRORS{UNKNOWN}; last; };
+#     /500 Internal Server Error/ &&
+#       do { $$asnmtapInherited->pluginValues ( { stateValue => $ERRORS{UNKNOWN}, error => $transportStatus }, $TYPE{REPLACE} ); return $ERRORS{UNKNOWN}; last; };
     }
 
     $$asnmtapInherited->pluginValues ( { stateValue => $ERRORS{CRITICAL}, alert => $transportStatus }, $TYPE{REPLACE} ); 
@@ -138,8 +140,8 @@ sub get_soap_request {
   sub _soapCheckFault {
     my ($asnmtapInherited, $som, $debug) = @_;
 
+    my $faultcode   = $som->faultcode; $faultcode =~ s/^\s+//g; $faultcode =~ s/\s+$//g;
     my $faultdetail = $som->faultdetail;
-    my $faultcode   = $som->faultcode;
     my $faultstring = $som->faultstring;
     my $faultactor  = $som->faultactor;
 
@@ -211,7 +213,7 @@ sub get_soap_request {
   my $returnCode = _soapCheckTransportStatus ($asnmtapInherited, $service, $debug);
 
   unless ( $returnCode ) {
-    unless ( defined $som->fault ) {
+    unless ( defined $som and defined $som->fault ) {
       $result = UNIVERSAL::isa($som => 'SOAP::SOM') ? (wantarray ? $som->paramsall : $som->result) : $som;
 
       if ( $debug ) {
@@ -243,6 +245,8 @@ sub get_soap_request {
     } else {
       $returnCode = _soapCheckFault ($asnmtapInherited, $som, $debug);
     }
+  } elsif ( $returnCode == $ERRORS{CRITICAL} ) {
+    $returnCode = _soapCheckFault ($asnmtapInherited, $som, $debug) if ( defined $som and defined $som->fault );
   }
 
   print "ASNMTAP::Asnmtap::Plugins::SOAP::get_soap_request: () <--\n" if ( $debug );
